==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-blocks/lib/tcp_connection.h <==
/* -*- c++ -*- */
/*
 * Copyright 2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_TCP_CONNECTION_H
#define INCLUDED_TCP_CONNECTION_H

#include <boost/array.hpp>
#include <boost/asio.hpp>
#include <gruel/pmt.h>

class gr_basic_block;

namespace gr {
  namespace blocks {

    class tcp_connection
    {
    private:
      boost::asio::ip::tcp::socket d_socket;
      boost::array<char, 10000> d_buf;
      std::string d_message;
      gr_basic_block *d_block;

      tcp_connection(boost::asio::io_service& io_service);
      
    public:
      typedef boost::shared_ptr<tcp_connection> sptr;
      
      static sptr make(boost::asio::io_service& io_service);

      boost::asio::ip::tcp::socket& socket() { return d_socket; };

      void start(gr_basic_block *block);
      void send(pmt::pmt_t vector);
      void handle_read(const boost::system::error_code& error, size_t bytes_transferred);
      void handle_write(const boost::system::error_code& error, size_t bytes_transferred) { }
    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_TCP_CONNECTION_H */

==> gnuradio_3.7.2.1.orig.tar.gz: gnuradio-3.7.2.1/gr-blocks/lib/tcp_connection.h <==
/* -*- c++ -*- */
/*
 * Copyright 2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_TCP_CONNECTION_H
#define INCLUDED_TCP_CONNECTION_H

#include <boost/array.hpp>
#include <boost/asio.hpp>
#include <pmt/pmt.h>

namespace gr {
  
  class basic_block;

  namespace blocks {

    class tcp_connection
    {
    private:
      boost::asio::ip::tcp::socket d_socket;
      boost::array<char, 10000> d_buf;
      std::string d_message;
      basic_block *d_block;

      tcp_connection(boost::asio::io_service& io_service);
      
    public:
      typedef boost::shared_ptr<tcp_connection> sptr;
      
      static sptr make(boost::asio::io_service& io_service);

      boost::asio::ip::tcp::socket& socket() { return d_socket; };

      void start(gr::basic_block *block);
      void send(pmt::pmt_t vector);
      void handle_read(const boost::system::error_code& error, size_t bytes_transferred);
      void handle_write(const boost::system::error_code& error, size_t bytes_transferred) { }
    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_TCP_CONNECTION_H */
